@@ -1,7 +1,7 @@
 from sm.misc.fn_cache import *
 from sm.misc.deser import *
 from sm.misc.funcs import *
-from sm.misc.remote_dict import *
+from sm.misc.big_dict import *
 from sm.misc.exp_manager import *
 from sm.misc.ontology_namespace import *
 import sm.misc.graph as G
